# -*- coding: utf-8 -*-
from datetime import datetime
from dateutil.relativedelta import relativedelta
from odoo.tools import DEFAULT_SERVER_DATETIME_FORMAT

def create_download(cr, date, module_id, quantity):
    date = datetime.strftime(date, DEFAULT_SERVER_DATETIME_FORMAT)
    cr.execute("""INSERT INTO loempia_module_download (date, module_id, quantity)
                  VALUES (%s, %s, %s)
               """, [date, module_id, quantity])

def migrate(cr, version):
    cr.execute("""SELECT id, create_date, download_count from loempia_module where download_count > 0""")

    for (module_id, create_date, download_count) in cr.fetchall():
        # Spread out download counts daily since the creation date of the module
        create_date = datetime.strptime(create_date[:19], DEFAULT_SERVER_DATETIME_FORMAT)
        module_existance_duration = (datetime.now() - create_date).days
        average_daily_download_count = max(1, int(download_count / (module_existance_duration or 1)))
        days = 0
        while download_count > 0:
            daily_downloads = min(average_daily_download_count, download_count)
            create_download(cr, datetime.now()-relativedelta(days=days), module_id, daily_downloads)
            download_count -= daily_downloads
            days+=1
        cr.commit()
